import { Component, OnInit, Input, OnDestroy } from '@angular/core';
import { Job } from '../job';
import {TesService} from '../tes.service';
import { StrudelappsService } from '../strudelapps.service';
import { timer, Subscription } from 'rxjs';
import { repeat } from 'rxjs/operators';
import { AppAction, Strudelapp} from '../strudelapp';

@Component({
  selector: 'app-job',
  templateUrl: './job.component.html',
  styleUrls: ['./job.component.css']
})
export class JobComponent implements OnInit, OnDestroy {

  @Input() jobdata: Job;
  public available: Boolean;
  public nocancel: Boolean;
  public resources: string;
  public cpu_resources: string;
  public mem_resources: string;
  public timeremaining: string;
  private updatesub: Subscription;
  constructor(private tesService: TesService, private strudelAppsService: StrudelappsService) {



}


  ngOnDestroy() {
    this.updatesub.unsubscribe();
  }
  ngOnInit() {
    this.updatesub = timer(1000).pipe(repeat()).subscribe(() => this.updateFields());
  }

  parseDate(date) {
    const parsed = Date.parse(date);
    if (!isNaN(parsed)) {
      return parsed;
    }

      return Date.parse(date.replace(/-/g, '/').replace(/[a-z]+/gi, ' '));
  }

  updateFields() {
    if (this.jobdata.state == "RUNNING") {
      this.available = true;
    } else {
      this.available = false;
    }
    if (this.jobdata.app != null) {
      if (this.jobdata.app.startscript === null) {
        this.nocancel = true;
      } else {
        this.nocancel = false;
      }
    } else {
      this.nocancel = false;
    }
    if (this.jobdata.state == "Finished") {
      this.nocancel = true;
    }
    this.resources="";
    this.cpu_resources = "";
    this.mem_resources = "";
    if (this.jobdata.cpus != undefined) {
        this.cpu_resources = this.cpu_resources+"CPUs: "+this.jobdata.cpus;
    }
    if (this.jobdata.mem != undefined) {
        this.mem_resources = this.mem_resources+"Mem: "+this.jobdata.mem;
    }
    if (this.jobdata.endtime != undefined) {
        let end = this.parseDate(this.jobdata.endtime);
        let remaining = end.valueOf() - Date.now().valueOf();
        this.timeremaining = this.secondsToHms(remaining/1000);
    } 
  }

  secondsToHms(d: number) {
    var h: number = Math.floor(d / 3600);
    var m: number = Math.floor(d % 3600 / 60);
    var s: number = Math.floor(d % 3600 % 60);

    var hDisplay = h > 0 ? h + (h == 1 ? " hour " : " hours ") : "";
    var mDisplay = m > 0 ? m + (m == 1 ? " minute " : " minutes ") : "";
    return hDisplay + mDisplay ; 
  }

  onCancel() {
    this.tesService.cancel(this.jobdata);
  }

  onConnect(action: AppAction) {
    console.log('called on connect');
    console.log(action)
    // Before connecting we must resolve what type of app we are connecting to
    // this.jobdata.app = this.strudelAppsService.getApp(this.jobdata.name);
    this.tesService.connect(this.jobdata,action);
  }

}
